@@ -20,7 +20,7 @@ Readonly::Array our @EXPORT_OK => qw(first_male first_female middle_female
 our $TYPE = 'three';
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # First and middle male names.
 our @first_male = our @middle_male = qw(
@@ -126,7 +126,7 @@ Willem
 Yannik
 );
 
-# First nad middle female names.
+# First and middle female names.
 our @first_female = our @middle_female = qw(
 Alexandra
 Amelie
@@ -650,13 +650,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Mock::Person>,
-L<Mock::Person::CZ>,
-L<Mock::Person::EN>,
-L<Mock::Person::SK>,
-L<Mock::Person::SK::ROM>,
-L<Mock::Person::SV>,
-L<Mock::Person::RU>.
+=over
+
+=item L<Task::Mock::Person>
+
+Install the Mock::Person modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -670,10 +670,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © Michal Špaček 2013-2015
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
